CrateInfo

Struct CrateInfo 

pub struct CrateInfo { /* private fields */ }
Information about a crate (which may be in-workspace or a dependency).

Implementations

Source

impl CrateInfo

pub fn name(&self) -> &str

The name of the crate.

pub fn version(&self) -> &Version

The version of the crate.

pub fn library_target_name(&self) -> Option<&str>

The name of the crate’s root library target. This is the target that a dependent would get if they were to depend on this crate.

pub fn is_proc_macro(&self) -> bool

Whether the crate is a procedural macro.

pub fn normal_deps(&self) -> Select<BTreeSet<CrateDependency>>

Dependencies required to compile the crate, without procedural macro dependencies.

pub fn dev_deps(&self) -> Select<BTreeSet<CrateDependency>>

Dependencies required to compile the tests for the crate, but not needed to compile the crate itself, without procedural macro dependencies.

pub fn proc_macro_deps(&self) -> Select<BTreeSet<CrateDependency>>

Procedural macro dependencies required to compile the crate.

pub fn proc_macro_dev_deps(&self) -> Select<BTreeSet<CrateDependency>>

Procedural macro dependencies required to compile the tests for the crate, but not needed to compile the crate itself.