Enum cargo_bazel::cli::Options
source · pub enum Options {
Generate(GenerateOptions),
Splice(SpliceOptions),
Query(QueryOptions),
Vendor(VendorOptions),
}Variants
Generate(GenerateOptions)
Generate Bazel Build files from a Cargo manifest.
Splice(SpliceOptions)
Splice together disjoint Cargo and Bazel info into a single Cargo workspace manifest.
Query(QueryOptions)
Query workspace info to determine whether or not a repin is needed.
Vendor(VendorOptions)
Vendor BUILD files to the workspace with either repository definitions or cargo vendor generated sources.