Function cargo_bazel::cli::query
source · pub fn query(opt: QueryOptions) -> Result<()>Expand description
Determine if the current lockfile needs to be re-pinned
pub fn query(opt: QueryOptions) -> Result<()>Determine if the current lockfile needs to be re-pinned