pub struct GenerateOptions {Show 14 fields
pub cargo: Option<PathBuf>,
pub rustc: Option<PathBuf>,
pub config: PathBuf,
pub splicing_manifest: PathBuf,
pub lockfile: Option<PathBuf>,
pub cargo_lockfile: PathBuf,
pub repository_dir: PathBuf,
pub cargo_config: Option<PathBuf>,
pub repin: bool,
pub metadata: Option<PathBuf>,
pub dry_run: bool,
pub nonhermetic_root_bazel_workspace_dir: Utf8PathBuf,
pub paths_to_track: PathBuf,
pub warnings_output_path: PathBuf,
/* private fields */
}Expand description
Command line options for the generate subcommand
Fields
cargo: Option<PathBuf>The path to a Cargo binary to use for gathering metadata
rustc: Option<PathBuf>The path to a rustc binary for use with Cargo
config: PathBufThe config file with information about the Bazel and Cargo workspace
splicing_manifest: PathBufA generated manifest of splicing inputs
lockfile: Option<PathBuf>The path to either a Cargo or Bazel lockfile
cargo_lockfile: PathBufThe path to a Cargo.lock file.
repository_dir: PathBufThe directory of the current repository rule
cargo_config: Option<PathBuf>A Cargo config file to use when gathering metadata
repin: boolWhether or not to ignore the provided lockfile and re-generate one
metadata: Option<PathBuf>The path to a Cargo metadata json file. This file must be next to a Cargo.toml and Cargo.lock file.
dry_run: boolIf true, outputs will be printed instead of written to disk.
nonhermetic_root_bazel_workspace_dir: Utf8PathBufThe path to the Bazel root workspace (i.e. the directory containing the WORKSPACE.bazel file or similar). BE CAREFUL with this value. We never want to include it in a lockfile hash (to keep lockfiles portable), which means you also should not use it anywhere that should be guarded by a lockfile hash. You basically never want to use this value.
paths_to_track: PathBufPath to write a list of files which the repository_rule should watch. If any of these paths change, the repository rule should be rerun. These files may be outside of the Bazel-managed workspace. A (possibly empty) JSON sorted array of strings will be unconditionally written to this file.
warnings_output_path: PathBufPath to write a list of warnings which the repository rule should emit. A (possibly empty) JSON array of strings will be unconditionally written to this file. Each warning should be printed. This mechanism exists because this process’s output is often hidden by default, so this provides a way for the repository rule to force printing.