pub struct SpliceOptions {Show 13 fields
pub splicing_manifest: PathBuf,
pub cargo_lockfile: Option<PathBuf>,
pub repin: Option<CargoUpdateRequest>,
pub workspace_dir: Option<Utf8PathBuf>,
pub output_dir: PathBuf,
pub dry_run: bool,
pub cargo_config: Option<PathBuf>,
pub config: PathBuf,
pub cargo: PathBuf,
pub rustc: PathBuf,
pub repository_name: String,
pub skip_cargo_lockfile_overwrite: bool,
pub nonhermetic_root_bazel_workspace_dir: Utf8PathBuf,
}Expand description
Command line options for the splice subcommand
Fields
splicing_manifest: PathBufA generated manifest of splicing inputs
cargo_lockfile: Option<PathBuf>The path to a Cargo.lock file.
repin: Option<CargoUpdateRequest>The desired update/repin behavior
workspace_dir: Option<Utf8PathBuf>The directory in which to build the workspace. If this argument is not passed, a temporary directory will be generated.
output_dir: PathBufThe location where the results of splicing are written.
dry_run: boolIf true, outputs will be printed instead of written to disk.
cargo_config: Option<PathBuf>The path to a Cargo configuration file.
config: PathBufThe path to the config file (containing [crate::config::Config].)
cargo: PathBufThe path to a Cargo binary to use for gathering metadata
rustc: PathBufThe path to a rustc binary for use with Cargo
repository_name: StringThe name of the repository being generated.
skip_cargo_lockfile_overwrite: boolWhether to skip writing the cargo lockfile back after resolving. You may want to set this if your dependency versions are maintained externally through a non-trivial set-up. But you probably don’t want to set this.
nonhermetic_root_bazel_workspace_dir: Utf8PathBufThe path to the Bazel root workspace (i.e. the directory containing the WORKSPACE.bazel file or similar). BE CAREFUL with this value. We never want to include it in a lockfile hash (to keep lockfiles portable), which means you also should not use it anywhere that should be guarded by a lockfile hash. You basically never want to use this value.