pub struct CrateInfo { /* private fields */ }Expand description
Information about a crate (which may be in-workspace or a dependency).
Implementations
Sourceimpl CrateInfo
impl CrateInfo
Sourcepub fn library_target_name(&self) -> Option<&str>
pub fn library_target_name(&self) -> Option<&str>
The name of the crate’s root library target. This is the target that a dependent would get if they were to depend on this crate.
Sourcepub fn is_proc_macro(&self) -> bool
pub fn is_proc_macro(&self) -> bool
Whether the crate is a procedural macro.
Sourcepub fn normal_deps(&self) -> Select<BTreeSet<CrateDependency>>
pub fn normal_deps(&self) -> Select<BTreeSet<CrateDependency>>
Dependencies required to compile the crate, without procedural macro dependencies.
Sourcepub fn dev_deps(&self) -> Select<BTreeSet<CrateDependency>>
pub fn dev_deps(&self) -> Select<BTreeSet<CrateDependency>>
Dependencies required to compile the tests for the crate, but not needed to compile the crate itself, without procedural macro dependencies.
Sourcepub fn proc_macro_deps(&self) -> Select<BTreeSet<CrateDependency>>
pub fn proc_macro_deps(&self) -> Select<BTreeSet<CrateDependency>>
Procedural macro dependencies required to compile the crate.
Sourcepub fn proc_macro_dev_deps(&self) -> Select<BTreeSet<CrateDependency>>
pub fn proc_macro_dev_deps(&self) -> Select<BTreeSet<CrateDependency>>
Procedural macro dependencies required to compile the tests for the crate, but not needed to compile the crate itself.