Module cargo_bazel::cli
source · Expand description
Command line interface entry points and utilities
Structs
- Command line options for the
generatesubcommand - Command line options for the
querysubcommand - Command line options for the
splicesubcommand - Command line options for the
vendorsubcommand
Enums
Functions
- Determine if the current lockfile needs to be re-pinned
- Combine a set of disjoint manifests into a single workspace.