Struct cargo_bazel::cli::GenerateOptions
source · pub struct GenerateOptions {
pub cargo: Option<PathBuf>,
pub rustc: Option<PathBuf>,
pub config: PathBuf,
pub splicing_manifest: PathBuf,
pub lockfile: Option<PathBuf>,
pub cargo_lockfile: PathBuf,
pub repository_dir: PathBuf,
pub cargo_config: Option<PathBuf>,
pub repin: bool,
pub metadata: Option<PathBuf>,
pub dry_run: bool,
}Expand description
Command line options for the generate subcommand
Fields
cargo: Option<PathBuf>The path to a Cargo binary to use for gathering metadata
rustc: Option<PathBuf>The path to a rustc binary for use with Cargo
config: PathBufThe config file with information about the Bazel and Cargo workspace
splicing_manifest: PathBufA generated manifest of splicing inputs
lockfile: Option<PathBuf>The path to either a Cargo or Bazel lockfile
cargo_lockfile: PathBufThe path to a Cargo.lock file.
repository_dir: PathBufThe directory of the current repository rule
cargo_config: Option<PathBuf>A Cargo config file to use when gathering metadata
repin: boolWhether or not to ignore the provided lockfile and re-generate one
metadata: Option<PathBuf>The path to a Cargo metadata json file. This file must be next to a Cargo.toml and Cargo.lock file.
dry_run: boolIf true, outputs will be printed instead of written to disk.