Struct cargo_bazel::cli::QueryOptions
source · pub struct QueryOptions {
pub lockfile: PathBuf,
pub config: PathBuf,
pub splicing_manifest: PathBuf,
pub cargo: PathBuf,
pub rustc: PathBuf,
}Expand description
Command line options for the query subcommand
Fields
lockfile: PathBufThe lockfile path for reproducible Cargo->Bazel renderings
config: PathBufThe config file with information about the Bazel and Cargo workspace
splicing_manifest: PathBufA generated manifest of splicing inputs
cargo: PathBufThe path to a Cargo binary to use for gathering metadata
rustc: PathBufThe path to a rustc binary for use with Cargo