Struct cargo_bazel::cli::SpliceOptions
source · pub struct SpliceOptions {
pub splicing_manifest: PathBuf,
pub cargo_lockfile: Option<PathBuf>,
pub repin: Option<CargoUpdateRequest>,
pub workspace_dir: Option<PathBuf>,
pub output_dir: PathBuf,
pub dry_run: bool,
pub cargo_config: Option<PathBuf>,
pub config: PathBuf,
pub cargo: PathBuf,
pub rustc: PathBuf,
}Expand description
Command line options for the splice subcommand
Fields
splicing_manifest: PathBufA generated manifest of splicing inputs
cargo_lockfile: Option<PathBuf>The path to a Cargo.lock file.
repin: Option<CargoUpdateRequest>The desired update/repin behavior
workspace_dir: Option<PathBuf>The directory in which to build the workspace. If this argument is not passed, a temporary directory will be generated.
output_dir: PathBufThe location where the results of splicing are written.
dry_run: boolIf true, outputs will be printed instead of written to disk.
cargo_config: Option<PathBuf>The path to a Cargo configuration file.
config: PathBufThe path to the config file (containing cargo_bazel::config::Config.)
cargo: PathBufThe path to a Cargo binary to use for gathering metadata
rustc: PathBufThe path to a rustc binary for use with Cargo