pub struct VendorOptions {Show 13 fields
pub cargo: PathBuf,
pub rustc: PathBuf,
pub buildifier: Option<PathBuf>,
pub config: PathBuf,
pub splicing_manifest: PathBuf,
pub cargo_lockfile: Option<PathBuf>,
pub cargo_config: Option<PathBuf>,
pub repin: Option<CargoUpdateRequest>,
pub metadata: Option<PathBuf>,
pub bazel: PathBuf,
pub workspace_dir: PathBuf,
pub dry_run: bool,
pub nonhermetic_root_bazel_workspace_dir: Utf8PathBuf,
}Expand description
Command line options for the vendor subcommand
Fields
cargo: PathBufThe path to a Cargo binary to use for gathering metadata
rustc: PathBufThe path to a rustc binary for use with Cargo
buildifier: Option<PathBuf>The path to a buildifier binary for formatting generated BUILD files
config: PathBufThe config file with information about the Bazel and Cargo workspace
splicing_manifest: PathBufA generated manifest of splicing inputs
cargo_lockfile: Option<PathBuf>The path to a Cargo.lock file.
cargo_config: Option<PathBuf>A Cargo config file to use when gathering metadata
repin: Option<CargoUpdateRequest>The desired update/repin behavior. The arguments passed here are forward to cargo update. See [crate::metadata::CargoUpdateRequest] for details on the values to pass here.
metadata: Option<PathBuf>The path to a Cargo metadata json file.
bazel: PathBufThe path to a bazel binary
workspace_dir: PathBufThe directory in which to build the workspace. A Cargo.toml file
should always be produced within this directory.
dry_run: boolIf true, outputs will be printed instead of written to disk.
nonhermetic_root_bazel_workspace_dir: Utf8PathBufThe path to the Bazel root workspace (i.e. the directory containing the WORKSPACE.bazel file or similar). BE CAREFUL with this value. We never want to include it in a lockfile hash (to keep lockfiles portable), which means you also should not use it anywhere that should be guarded by a lockfile hash. You basically never want to use this value.